drmtap_list_devices

Function drmtap_list_devices 

pub unsafe extern "C" fn drmtap_list_devices(
    out: *mut drmtap_device,
    max_count: c_int,
) -> c_int
Enumerate every DRM device with KMS resources. A context is bound to one device, so this is how a multi-GPU consumer finds the other cards instead of only ever advertising the displays of the first one.